@@ -69,7 +69,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   nil,
-				preRead: []map[string]string{{}},
+				preRead: []map[string]interface{}{{}},
 			},
 			wantErr: false,
 		},
@@ -81,7 +81,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1", "c2"},
-				preRead: []map[string]string{{"c1": "1", "c2": "Orange"}, {"c1": "2", "c2": "Melon"}, {"c1": "3", "c2": "Apple"}},
+				preRead: []map[string]interface{}{{"c1": "1", "c2": "Orange"}, {"c1": "2", "c2": "Melon"}, {"c1": "3", "c2": "Apple"}},
 			},
 			wantErr: false,
 		},
@@ -96,7 +96,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1", "c2"},
-				preRead: []map[string]string{{"c1": "1", "c2": "Orange"}},
+				preRead: []map[string]interface{}{{"c1": "1", "c2": "Orange"}},
 			},
 			wantErr: false,
 		},
@@ -108,7 +108,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1"},
-				preRead: []map[string]string{{"c1": "[\"a\"]"}, {"c1": "[\"b\"]"}},
+				preRead: []map[string]interface{}{{"c1": "[\"a\"]"}, {"c1": "[\"b\"]"}},
 			},
 			wantErr: false,
 		},
@@ -120,7 +120,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1"},
-				preRead: []map[string]string{{"c1": "[\"a\",\"b\"]"}, {"c1": "[\"c\",\"d\"]"}},
+				preRead: []map[string]interface{}{{"c1": "[\"a\",\"b\"]"}, {"c1": "[\"c\",\"d\"]"}},
 			},
 			wantErr: false,
 		},
@@ -132,7 +132,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1"},
-				preRead: []map[string]string{{"c1": "a"}, {"c1": "b"}},
+				preRead: []map[string]interface{}{{"c1": "a"}, {"c1": "b"}},
 			},
 			wantErr: false,
 		},
@@ -144,7 +144,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"a"},
-				preRead: []map[string]string{{"a": "b"}},
+				preRead: []map[string]interface{}{{"a": "b"}},
 			},
 			wantErr: false,
 		},
@@ -160,7 +160,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"id", "name"},
-				preRead: []map[string]string{{"id": "1", "name": "Orange"}},
+				preRead: []map[string]interface{}{{"id": "1", "name": "Orange"}},
 			},
 			wantErr: false,
 		},
@@ -176,7 +176,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names: []string{"id", "name", "color"},
-				preRead: []map[string]string{
+				preRead: []map[string]interface{}{
 					{"id": "1", "name": "Orange"},
 					{"id": "2", "name": "Melon"},
 					{"id": "3", "name": "Apple"},
@@ -193,7 +193,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names:   []string{"c1", "c2"},
-				preRead: []map[string]string{{"c1": "1", "c2": "Orange"}},
+				preRead: []map[string]interface{}{{"c1": "1", "c2": "Orange"}},
 			},
 			wantErr: false,
 		},
@@ -209,7 +209,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names: []string{"name", "email"},
-				preRead: []map[string]string{
+				preRead: []map[string]interface{}{
 					{"name": "Shyam", "email": "shyamjaiswal@gmail.com"},
 					{"name": "Bob", "email": "bob32@gmail.com"},
 					{"name": "Jai", "email": "jai87@gmail.com"},
@@ -235,7 +235,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names: []string{"value", "onclick"},
-				preRead: []map[string]string{
+				preRead: []map[string]interface{}{
 					{"value": "New", "onclick": "CreateDoc()"},
 					{"value": "Open", "onclick": "OpenDoc()"},
 					{"value": "Save", "onclick": "SaveDoc()"},
@@ -252,7 +252,7 @@ func TestNewJSONReader(t *testing.T) {
 			},
 			want: &JSONReader{
 				names: []string{"id"},
-				preRead: []map[string]string{
+				preRead: []map[string]interface{}{
 					{"id": "1"},
 					{"id": "2"},
 					{"id": "3"},
@@ -277,3 +277,82 @@ func TestNewJSONReader(t *testing.T) {
 		})
 	}
 }
+
+func TestNewJSONReaderWithNULL(t *testing.T) {
+	type args struct {
+		reader io.Reader
+		opts   *ReadOpts
+	}
+	tests := []struct {
+		name    string
+		args    args
+		want    *JSONReader
+		wantErr bool
+	}{
+		{
+			name: "testNULL1",
+			args: args{
+				reader: strings.NewReader(`[{"id":1},{"id":null},{"id":3}]`),
+				opts:   NewReadOpts(),
+			},
+			want: &JSONReader{
+				names: []string{"id"},
+				preRead: []map[string]interface{}{
+					{"id": "1"},
+					{"id": nil},
+					{"id": "3"},
+				},
+			},
+			wantErr: false,
+		},
+		{
+			name: "testNULL2",
+			args: args{
+				reader: strings.NewReader(`[{"id":1},{"id":"N"},{"id":3}]`),
+				opts: NewReadOpts(
+					InNeedNULL(true),
+					InNULL("N"),
+				),
+			},
+			want: &JSONReader{
+				names: []string{"id"},
+				preRead: []map[string]interface{}{
+					{"id": "1"},
+					{"id": nil},
+					{"id": "3"},
+				},
+			},
+			wantErr: false,
+		},
+		{
+			name: "testNULL3",
+			args: args{
+				reader: strings.NewReader(`[{"c1":"1","c2":null},{"c1":"2","c2":"\\N"},{"c1":"3","c2":"Apple"}]`),
+				opts: NewReadOpts(
+					InNeedNULL(true),
+					InNULL("\\N"),
+				),
+			},
+			want: &JSONReader{
+				names:   []string{"c1", "c2"},
+				preRead: []map[string]interface{}{{"c1": "1", "c2": nil}, {"c1": "2", "c2": nil}, {"c1": "3", "c2": "Apple"}},
+			},
+			wantErr: false,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			got, err := NewJSONReader(tt.args.reader, tt.args.opts)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("NewJSONReader() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			if !arraySortEqual(t, got.names, tt.want.names) {
+				t.Errorf("NewJSONReader() = %v, want %v", got.names, tt.want.names)
+			}
+			if !reflect.DeepEqual(got.preRead, tt.want.preRead) {
+				t.Errorf("NewJSONReader() = %v, want %v", got.preRead, tt.want.preRead)
+			}
+		})
+	}
+}
