@@ -8,23 +8,18 @@ import (
 
 // TWWriter provides methods of the Writer interface.
 type TWWriter struct {
-	writer   *tablewriter.Table
-	outNULL  string
-	results  []string
-	needNULL bool
-	markdown bool
+	writeOpts *WriteOpts
+	writer    *tablewriter.Table
+	outNULL   string
+	results   []string
+	needNULL  bool
+	markdown  bool
 }
 
 // NewTWWriter returns TWWriter.
 func NewTWWriter(writeOpts *WriteOpts, markdown bool) *TWWriter {
 	w := &TWWriter{}
-	w.writer = tablewriter.NewWriter(writeOpts.OutStream)
-	w.writer.SetAutoFormatHeaders(false)
-	w.writer.SetAutoWrapText(!writeOpts.OutNoWrap)
-	if markdown {
-		w.writer.SetBorders(tablewriter.Border{Left: true, Top: false, Right: true, Bottom: false})
-		w.writer.SetCenterSeparator("|")
-	}
+	w.writeOpts = writeOpts
 	w.needNULL = writeOpts.OutNeedNULL
 	w.outNULL = writeOpts.OutNULL
 	w.markdown = markdown
@@ -33,6 +28,13 @@ func NewTWWriter(writeOpts *WriteOpts, markdown bool) *TWWriter {
 
 // PreWrite is preparation.
 func (w *TWWriter) PreWrite(columns []string, types []string) error {
+	w.writer = tablewriter.NewWriter(w.writeOpts.OutStream)
+	w.writer.SetAutoFormatHeaders(false)
+	w.writer.SetAutoWrapText(!w.writeOpts.OutNoWrap)
+	if w.markdown {
+		w.writer.SetBorders(tablewriter.Border{Left: true, Top: false, Right: true, Bottom: false})
+		w.writer.SetCenterSeparator("|")
+	}
 	w.writer.SetHeader(columns)
 	w.results = make([]string, len(columns))
 
